@@ -44,13 +44,13 @@ private:
     Ui::MainWindow *ui;
 
     int maxVol;
-    const QStringList *sources;
+    QStringList *sources;
 
 private slots:
     void resetMaxValue();
     void setLinearScale();
     void setDbScale();
-    void sourceChanged(QString source);
+    void sourceChanged(int source);
     void updateValues(float value);
 };
 
