@@ -23,12 +23,14 @@
 #include <pulse/context.h>
 #include <pulse/introspect.h>
 
+#include <QStringList>
+
 #include "pa_context_helper.h"
 #include "pa_streams_helper.h"
 
 void get_source_info_list_callback(pa_context *context, const pa_source_info *info, int eol, void *data);
 
-const char *get_source_name();
+const QStringList *get_source_names();
 
 bool pa_available();
 
