@@ -82,7 +82,7 @@ void VolumeMeterWidget::draw(QPainter *painter){
         }
         painter->rotate(-50./110.*5.);
     }else{
-        for(int i = 0; i < 17; i++){
+        for(int i = 0; i < 16; i++){
             if(i % 4 == 0){
                 if(i >= 12){
                     thickPen.setColor(Qt::red);
@@ -90,7 +90,7 @@ void VolumeMeterWidget::draw(QPainter *painter){
 
                 painter->setPen(thickPen);
                 painter->drawLine(0, -297, 0, -315);
-                painter->drawText(-20, -335, 40, 20, Qt::AlignCenter, QString().setNum((i/4)*50));
+                painter->drawText(-20, -338, 40, 20, Qt::AlignCenter, QString().setNum((i/4)*50));
             }else{
                 if(i >= 12){
                     thinPen.setColor(Qt::red);
@@ -106,7 +106,9 @@ void VolumeMeterWidget::draw(QPainter *painter){
 
             painter->rotate(50./200.*12.5);
         }
-        painter->rotate(-50./200.*12.5);
+
+        painter->setPen(thickPen);
+        painter->drawLine(0, -297, 0, -315);
     }
 
     painter->rotate(-25);
